Welcome to skippa's documentation!
======================================


.. toctree::
   :maxdepth: 2
   :caption: Contents:

   introduction
   skippa

.. include:: introduction.rst

Modules
=======

.. automodule:: skippa
   :noindex:
   :members:

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
